@@ -8,7 +8,7 @@ taskList = [
     T(8000, scope.l560.TurnOn),
     T(maxint, scope.turnAllLasersOff),
     T(maxint, scope.focus_lock.EnableLock),
-    T(maxint, scope.spoolController.LaunchAnalysis)
+    # T(maxint, scope.spoolController.LaunchAnalysis)
 ]
 
 metaData = [
