@@ -25,7 +25,15 @@ from PYME.IO import tabular
 from PYME.IO.image import ImageBounds
 from PYME.LMVis import dyeRatios
 from PYME.LMVis import statusLog
-from PYME.LMVis.triBlobs import BlobSettings
+
+try:
+    # make sure pipeline works when wx is not avalable
+    # TODO - move blob stuff into a recipe module and remove from pipeline.
+    from PYME.LMVis.triBlobs import BlobSettings
+except ImportError:
+    # create a dummy class
+    class BlobSettings:
+        pass
 
 from PYME.Analysis import piecewiseMapping
 from PYME.IO import MetaDataHandler
@@ -631,11 +639,12 @@ class Pipeline:
 
         Returns
         -------
-
-        ds : the dataset
+        ds : tabular.TabularBase
+            the datasource, complete with metadatahandler and events if found.
 
         """
-
+        mdh = MetaDataHandler.NestedClassMDHandler()
+        events = None
         if os.path.splitext(filename)[1] == '.h5r':
             import tables
             h5f = tables.open_file(filename)
@@ -662,36 +671,32 @@ class Pipeline:
                 self.addDataSource('Fiducials', self.driftInputMapping)
                 #self.selectDataSource('Fiducials')
 
-            #catch really old files which don't have any metadata
+            # really old files might not have metadata, so test for it before assuming
             if 'MetaData' in h5f.root:
-                self.mdh.copyEntriesFrom(MetaDataHandler.HDFMDHandler(h5f))
-
-            if ('Events' in h5f.root) and ('StartTime' in self.mdh.keys()):
-                self.events = h5f.root.Events[:]
+                mdh = MetaDataHandler.HDFMDHandler(h5f)
+            
+            if ('Events' in h5f.root) and ('StartTime' in mdh.keys()):
+                events = h5f.root.Events[:]
 
         elif filename.endswith('.hdf'):
             #recipe output - handles generically formatted .h5
             import tables
             h5f = tables.open_file(filename)
             self.filesToClose.append(h5f)
-
-            for t in h5f.list_nodes('/'):
-                if isinstance(t, tables.table.Table):
-                    tab = tabular.HDFSource(h5f, t.name)
-                    self.addDataSource(t.name, tab)
-                        
-                    if 'EventName' in t.description._v_names: #FIXME - we shouldn't have a special case here
-                        self.events = t[:]  # this does not handle multiple events tables per hdf file
-
-            if 'MetaData' in h5f.root:
-                self.mdh.copyEntriesFrom(MetaDataHandler.HDFMDHandler(h5f))
+            
+            #defer our IO to the recipe IO method - TODO - do this for other file types as well
+            self.recipe._inject_tables_from_hdf5('', h5f, filename, '.hdf')
 
             for dsname, ds_ in self.dataSources.items():
                 #loop through tables until we get one which defines x. If no table defines x, take the last table to be added
                 #TODO make this logic better.
-                ds = ds_.resultsSource
+                ds = ds_
                 if 'x' in ds.keys():
+                    # TODO - get rid of some of the grossness here
+                    mdh = getattr(ds, 'mdh', mdh)
+                    events = getattr(ds, 'events', events)
                     break
+                    
 
         elif os.path.splitext(filename)[1] == '.mat': #matlab file
             if 'VarName' in kwargs.keys():
@@ -722,12 +727,16 @@ class Pipeline:
                 ds = tabular.TextfileSource(filename, kwargs['FieldNames'], skiprows=kwargs['SkipRows'])
             else:
                 ds = tabular.TextfileSource(filename, kwargs['FieldNames'])
-
-
-
+        
+        # make sure mdh is writable (file-based might not be)
+        ds.mdh = MetaDataHandler.NestedClassMDHandler(mdToCopy=mdh)
+        if events is not None:
+            # only set the .events attribute if we actually have events.
+            ds.events = events
+            
         return ds
 
-    def OpenFile(self, filename= '', ds = None, **kwargs):
+    def OpenFile(self, filename= '', ds = None, clobber_recipe=True, **kwargs):
         """Open a file - accepts optional keyword arguments for use with files
         saved as .txt and .mat. These are:
             
@@ -741,12 +750,21 @@ class Pipeline:
             
         """
         
+
         #close any files we had open previously
         while len(self.filesToClose) > 0:
             self.filesToClose.pop().close()
         
-        #clear our state
+        # clear our state
+        # nb - equivalent to clearing recipe namespace
         self.dataSources.clear()
+        
+        if clobber_recipe:
+            # clear any processing modules from the pipeline
+            # call with clobber_recipe = False in a 'Open a new file with the processing pipeline I've set up' use case
+            # TODO: Add an "File-->Open [preserving recipe]" menu option or similar
+            self.recipe.modules = []
+        
         if 'zm' in dir(self):
             del self.zm
         self.filter = None
@@ -767,67 +785,59 @@ class Pipeline:
                 # that _ds_from_file() copies the data, but potentially keeps the file open which could be problematic.
                 # This won't effect local file loading even if loading is lazy (i.e. shouldn't cause a regression)
                 ds = self._ds_from_file(fn, **kwargs)
+                self.events = getattr(ds, 'events', None)
+                self.mdh.copyEntriesFrom(ds.mdh)
 
-            
-        #wrap the data source with a mapping so we can fiddle with things
-        #e.g. combining z position and focus 
-        mapped_ds = tabular.MappingFilter(ds)
+        # skip the MappingFilter wrapping, etc. in self.addDataSource and add this datasource as-is
+        self.dataSources['FitResults'] = ds
 
-        
-        if 'PixelSize' in kwargs.keys():
-            mapped_ds.addVariable('pixelSize', kwargs['PixelSize'])
-            mapped_ds.setMapping('x', 'x*pixelSize')
-            mapped_ds.setMapping('y', 'y*pixelSize')
-
-        #extract information from any events
-        self.ev_mappings, self.eventCharts = _processEvents(mapped_ds, self.events, self.mdh)
-
-
-
-        #Fit module specific filter settings        
+        # Fit module specific filter settings
+        # TODO - put all the defaults here and use a local variable rather than in __init__ (self.filterKeys is largely an artifact of pre-recipe based pipeline)
         if 'Analysis.FitModule' in self.mdh.getEntryNames():
             fitModule = self.mdh['Analysis.FitModule']
-            
-            #print 'fitModule = %s' % fitModule
-            
             if 'Interp' in fitModule:
                 self.filterKeys['A'] = (5, 100000)
-            
-            if 'LatGaussFitFR' in fitModule:
-                mapped_ds.addColumn('nPhotons', getPhotonNums(mapped_ds, self.mdh))
-
-            if 'SplitterFitFNR' in fitModule:
-                mapped_ds.addColumn('nPhotonsg', getPhotonNums({'A': mapped_ds['fitResults_Ag'], 'sig': mapped_ds['fitResults_sigma']}, self.mdh))
-                mapped_ds.addColumn('nPhotonsr', getPhotonNums({'A': mapped_ds['fitResults_Ar'], 'sig': mapped_ds['fitResults_sigma']}, self.mdh))
-                mapped_ds.setMapping('nPhotons', 'nPhotonsg+nPhotonsr')
-
             if fitModule == 'SplitterShiftEstFR':
-                self.filterKeys['fitError_dx'] = (0,10)
-                self.filterKeys['fitError_dy'] = (0,10)
+                self.filterKeys['fitError_dx'] = (0, 10)
+                self.filterKeys['fitError_dy'] = (0, 10)
 
-        #self._get_dye_ratios_from_metadata()
-
-        self.addDataSource('Localizations', mapped_ds)
-
-        # Retrieve or estimate image bounds
-        if False:  # 'imgBounds' in kwargs.keys():
-            self.imageBounds = kwargs['imgBounds']
-        elif (not (
-                'scanx' in mapped_ds.keys() or 'scany' in mapped_ds.keys())) and 'Camera.ROIWidth' in self.mdh.getEntryNames():
-            self.imageBounds = ImageBounds.extractFromMetadata(self.mdh)
+        if clobber_recipe:
+            from PYME.recipes.localisations import ProcessColour, Pipelineify
+            from PYME.recipes.tablefilters import FilterTable
+            
+            add_pipeline_variables = Pipelineify(self.recipe,
+                inputFitResults='FitResults',
+                pixelSizeNM=kwargs.get('PixelSize', 1.),
+                outputLocalizations='Localizations')
+            self.recipe.add_module(add_pipeline_variables)
+          
+            #self._get_dye_ratios_from_metadata()
+                   
+            colour_mapper = ProcessColour(self.recipe, input='Localizations', output='colour_mapped')
+            self.recipe.add_module(colour_mapper)
+            self.recipe.add_module(FilterTable(self.recipe, inputName='colour_mapped', outputName='filtered_localizations', filters={k:list(v) for k, v in self.filterKeys.items() if k in ds.keys()}))
         else:
-            self.imageBounds = ImageBounds.estimateFromSource(mapped_ds)
-
-        from PYME.recipes.localisations import ProcessColour
-        from PYME.recipes.tablefilters import FilterTable
+            logger.warn('Opening file without clobbering recipe, filter and ratiometric colour settings might not be handled properly')
+            # FIXME - should we update filter keys and/or make the filter more robust
+            # FIXME - do we need to do anything about colour settings?
         
-        colour_mapper = ProcessColour(self.recipe, input='Localizations', output='colour_mapped')
-        #we keep a copy of this so that the colour panel can find it.
-        self.recipe.add_module(colour_mapper)
-        self.recipe.add_module(FilterTable(self.recipe, inputName='colour_mapped', outputName='filtered_localizations', filters={k:list(v) for k, v in self.filterKeys.items() if k in mapped_ds.keys()}))
         self.recipe.execute()
         self.filterKeys = {}
         self.selectDataSource('filtered_localizations') #NB - this rebuilds the pipeline
+
+        # FIXME - we do this already in pipelinify, maybe we can avoid doubling up?
+        self.ev_mappings, self.eventCharts = _processEvents(ds, self.events,
+                                                            self.mdh)  # extract information from any events
+        # Retrieve or estimate image bounds
+        if False:  # 'imgBounds' in kwargs.keys():
+            # TODO - why is this disabled? Current usage would appear to be when opening from LMAnalysis
+            # during real-time localization, to force image bounds to match raw data, but also potentially useful
+            # for other scenarios where metadata is not fully present.
+            self.imageBounds = kwargs['imgBounds']
+        elif ('scanx' not in self.selectedDataSource.keys() or 'scany' not in self.selectedDataSource.keys()) and 'Camera.ROIWidth' in self.mdh.getEntryNames():
+            self.imageBounds = ImageBounds.extractFromMetadata(self.mdh)
+        else:
+            self.imageBounds = ImageBounds.estimateFromSource(self.selectedDataSource)
         
         #self._process_colour()
         
@@ -1110,5 +1120,3 @@ class Pipeline:
 
 
 
-
-
