@@ -103,7 +103,7 @@ import threading
 import datetime
 import time
 from PYME.IO import h5File
-
+from PYME.IO.FileUtils.nameUtils import get_service_name
 #GPU status functions
 try:
     import pynvml
@@ -690,10 +690,12 @@ class PYMEHTTPRequestHandler(http.server.SimpleHTTPRequestHandler):
         Parameters
         ----------
         path: str
-            path to an hdf or h5r file on the dataserver computer. Append the part of the file to read after the file
-            extension, e.g. .h5r/Events. Return format (for arrays) can additionally be specified, as can slices
-            using the following syntax: test.h5r/FitResults.json?from=0&to=100. Supported array formats include json and
-            npy.
+            OS-translated path to an hdf or h5r file on the dataserver computer. 
+            Append the part of the file to read after the file extension, e.g. 
+            .h5r/Events. Return format (for arrays) can additionally be 
+            specified, as can slices
+            using the following syntax: test.h5r/FitResults.json?from=0&to=100. 
+            Supported array formats include json and npy.
 
         Returns
         -------
@@ -705,7 +707,8 @@ class PYMEHTTPRequestHandler(http.server.SimpleHTTPRequestHandler):
 
         # parse path
         ext = '.h5r' if '.h5r' in path else '.hdf'
-        filename, details = path.split(ext + '/')
+        # TODO - should we just use the the untranslated path?
+        filename, details = path.split(ext + os.sep)
         filename = filename + ext  # path to file on dataserver disk
         query = urlparse.urlparse(details).query
         details = details.strip('?' + query)
@@ -894,7 +897,14 @@ def main(protocol="HTTP/1.0"):
     os.chdir(options.root)
 
     if options.advertisements == 'local':
-        ns = sqlite_ns.getNS('_pyme-http')
+        # preference is to avoid zeroconf on clusterofone due to poor
+        # performance on crowded networks
+        if config.get('clusterIO-hybridns', True):
+            ns = sqlite_ns.getNS('_pyme-http')
+        else:
+            # if we aren't using the hybridns, we are using zeroconf in clusterIO
+            # TODO - warn that we might run into performance issues???
+            ns = pzc.getNS('_pyme-http')
         server_address = ('127.0.0.1', int(options.port))
         ip_addr = '127.0.0.1'
     else:
@@ -918,7 +928,7 @@ def main(protocol="HTTP/1.0"):
 
     #get the actual adress (port) we bound to
     sa = httpd.socket.getsockname()
-    service_name = 'PYMEDataServer [%s]: ' % options.server_filter + procName
+    service_name = get_service_name('PYMEDataServer [%s]' % options.server_filter)
     ns.register_service(service_name, ip_addr, sa[1])
 
     status['IPAddress'] = ip_addr
