@@ -173,7 +173,7 @@ class CaptionBar(wx.Window):
         wx.Window.__init__(self, parent, id, pos=pos,
                            size=(-1,cbstyle['HEIGHT']), style=wx.NO_BORDER)
 
-        self.style = cbstyle
+        self.style = dict(cbstyle)
         self.parent = parent
         self.caption = caption
         self.foldIcons = foldIcons
